
#ifndef TTKDISCRETEGRADIENT_EXPORT_H
#define TTKDISCRETEGRADIENT_EXPORT_H

#ifdef TTKDISCRETEGRADIENT_STATIC_DEFINE
#  define TTKDISCRETEGRADIENT_EXPORT
#  define TTKDISCRETEGRADIENT_NO_EXPORT
#else
#  ifndef TTKDISCRETEGRADIENT_EXPORT
#    ifdef ttkDiscreteGradient_EXPORTS
        /* We are building this library */
#      define TTKDISCRETEGRADIENT_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKDISCRETEGRADIENT_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKDISCRETEGRADIENT_NO_EXPORT
#    define TTKDISCRETEGRADIENT_NO_EXPORT 
#  endif
#endif

#ifndef TTKDISCRETEGRADIENT_DEPRECATED
#  define TTKDISCRETEGRADIENT_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKDISCRETEGRADIENT_DEPRECATED_EXPORT
#  define TTKDISCRETEGRADIENT_DEPRECATED_EXPORT TTKDISCRETEGRADIENT_EXPORT TTKDISCRETEGRADIENT_DEPRECATED
#endif

#ifndef TTKDISCRETEGRADIENT_DEPRECATED_NO_EXPORT
#  define TTKDISCRETEGRADIENT_DEPRECATED_NO_EXPORT TTKDISCRETEGRADIENT_NO_EXPORT TTKDISCRETEGRADIENT_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKDISCRETEGRADIENT_NO_DEPRECATED
#    define TTKDISCRETEGRADIENT_NO_DEPRECATED
#  endif
#endif

#endif /* TTKDISCRETEGRADIENT_EXPORT_H */
