
#ifndef TTKGRIDLAYOUT_EXPORT_H
#define TTKGRIDLAYOUT_EXPORT_H

#ifdef TTKGRIDLAYOUT_STATIC_DEFINE
#  define TTKGRIDLAYOUT_EXPORT
#  define TTKGRIDLAYOUT_NO_EXPORT
#else
#  ifndef TTKGRIDLAYOUT_EXPORT
#    ifdef ttkGridLayout_EXPORTS
        /* We are building this library */
#      define TTKGRIDLAYOUT_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKGRIDLAYOUT_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKGRIDLAYOUT_NO_EXPORT
#    define TTKGRIDLAYOUT_NO_EXPORT 
#  endif
#endif

#ifndef TTKGRIDLAYOUT_DEPRECATED
#  define TTKGRIDLAYOUT_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKGRIDLAYOUT_DEPRECATED_EXPORT
#  define TTKGRIDLAYOUT_DEPRECATED_EXPORT TTKGRIDLAYOUT_EXPORT TTKGRIDLAYOUT_DEPRECATED
#endif

#ifndef TTKGRIDLAYOUT_DEPRECATED_NO_EXPORT
#  define TTKGRIDLAYOUT_DEPRECATED_NO_EXPORT TTKGRIDLAYOUT_NO_EXPORT TTKGRIDLAYOUT_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKGRIDLAYOUT_NO_DEPRECATED
#    define TTKGRIDLAYOUT_NO_DEPRECATED
#  endif
#endif

#endif /* TTKGRIDLAYOUT_EXPORT_H */
