
#ifndef TTKBOTTLENECKDISTANCE_EXPORT_H
#define TTKBOTTLENECKDISTANCE_EXPORT_H

#ifdef TTKBOTTLENECKDISTANCE_STATIC_DEFINE
#  define TTKBOTTLENECKDISTANCE_EXPORT
#  define TTKBOTTLENECKDISTANCE_NO_EXPORT
#else
#  ifndef TTKBOTTLENECKDISTANCE_EXPORT
#    ifdef ttkBottleneckDistance_EXPORTS
        /* We are building this library */
#      define TTKBOTTLENECKDISTANCE_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKBOTTLENECKDISTANCE_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKBOTTLENECKDISTANCE_NO_EXPORT
#    define TTKBOTTLENECKDISTANCE_NO_EXPORT 
#  endif
#endif

#ifndef TTKBOTTLENECKDISTANCE_DEPRECATED
#  define TTKBOTTLENECKDISTANCE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKBOTTLENECKDISTANCE_DEPRECATED_EXPORT
#  define TTKBOTTLENECKDISTANCE_DEPRECATED_EXPORT TTKBOTTLENECKDISTANCE_EXPORT TTKBOTTLENECKDISTANCE_DEPRECATED
#endif

#ifndef TTKBOTTLENECKDISTANCE_DEPRECATED_NO_EXPORT
#  define TTKBOTTLENECKDISTANCE_DEPRECATED_NO_EXPORT TTKBOTTLENECKDISTANCE_NO_EXPORT TTKBOTTLENECKDISTANCE_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKBOTTLENECKDISTANCE_NO_DEPRECATED
#    define TTKBOTTLENECKDISTANCE_NO_DEPRECATED
#  endif
#endif

#endif /* TTKBOTTLENECKDISTANCE_EXPORT_H */
