
#ifndef TTKTOPOLOGICALSIMPLIFICATION_EXPORT_H
#define TTKTOPOLOGICALSIMPLIFICATION_EXPORT_H

#ifdef TTKTOPOLOGICALSIMPLIFICATION_STATIC_DEFINE
#  define TTKTOPOLOGICALSIMPLIFICATION_EXPORT
#  define TTKTOPOLOGICALSIMPLIFICATION_NO_EXPORT
#else
#  ifndef TTKTOPOLOGICALSIMPLIFICATION_EXPORT
#    ifdef ttkTopologicalSimplification_EXPORTS
        /* We are building this library */
#      define TTKTOPOLOGICALSIMPLIFICATION_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKTOPOLOGICALSIMPLIFICATION_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKTOPOLOGICALSIMPLIFICATION_NO_EXPORT
#    define TTKTOPOLOGICALSIMPLIFICATION_NO_EXPORT 
#  endif
#endif

#ifndef TTKTOPOLOGICALSIMPLIFICATION_DEPRECATED
#  define TTKTOPOLOGICALSIMPLIFICATION_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKTOPOLOGICALSIMPLIFICATION_DEPRECATED_EXPORT
#  define TTKTOPOLOGICALSIMPLIFICATION_DEPRECATED_EXPORT TTKTOPOLOGICALSIMPLIFICATION_EXPORT TTKTOPOLOGICALSIMPLIFICATION_DEPRECATED
#endif

#ifndef TTKTOPOLOGICALSIMPLIFICATION_DEPRECATED_NO_EXPORT
#  define TTKTOPOLOGICALSIMPLIFICATION_DEPRECATED_NO_EXPORT TTKTOPOLOGICALSIMPLIFICATION_NO_EXPORT TTKTOPOLOGICALSIMPLIFICATION_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKTOPOLOGICALSIMPLIFICATION_NO_DEPRECATED
#    define TTKTOPOLOGICALSIMPLIFICATION_NO_DEPRECATED
#  endif
#endif

#endif /* TTKTOPOLOGICALSIMPLIFICATION_EXPORT_H */
