
#ifndef TTKBARYCENTRICSUBDIVISION_EXPORT_H
#define TTKBARYCENTRICSUBDIVISION_EXPORT_H

#ifdef TTKBARYCENTRICSUBDIVISION_STATIC_DEFINE
#  define TTKBARYCENTRICSUBDIVISION_EXPORT
#  define TTKBARYCENTRICSUBDIVISION_NO_EXPORT
#else
#  ifndef TTKBARYCENTRICSUBDIVISION_EXPORT
#    ifdef ttkBarycentricSubdivision_EXPORTS
        /* We are building this library */
#      define TTKBARYCENTRICSUBDIVISION_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKBARYCENTRICSUBDIVISION_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKBARYCENTRICSUBDIVISION_NO_EXPORT
#    define TTKBARYCENTRICSUBDIVISION_NO_EXPORT 
#  endif
#endif

#ifndef TTKBARYCENTRICSUBDIVISION_DEPRECATED
#  define TTKBARYCENTRICSUBDIVISION_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKBARYCENTRICSUBDIVISION_DEPRECATED_EXPORT
#  define TTKBARYCENTRICSUBDIVISION_DEPRECATED_EXPORT TTKBARYCENTRICSUBDIVISION_EXPORT TTKBARYCENTRICSUBDIVISION_DEPRECATED
#endif

#ifndef TTKBARYCENTRICSUBDIVISION_DEPRECATED_NO_EXPORT
#  define TTKBARYCENTRICSUBDIVISION_DEPRECATED_NO_EXPORT TTKBARYCENTRICSUBDIVISION_NO_EXPORT TTKBARYCENTRICSUBDIVISION_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKBARYCENTRICSUBDIVISION_NO_DEPRECATED
#    define TTKBARYCENTRICSUBDIVISION_NO_DEPRECATED
#  endif
#endif

#endif /* TTKBARYCENTRICSUBDIVISION_EXPORT_H */
