
#ifndef TTKTOPOLOGICALCOMPRESSIONREADER_EXPORT_H
#define TTKTOPOLOGICALCOMPRESSIONREADER_EXPORT_H

#ifdef TTKTOPOLOGICALCOMPRESSIONREADER_STATIC_DEFINE
#  define TTKTOPOLOGICALCOMPRESSIONREADER_EXPORT
#  define TTKTOPOLOGICALCOMPRESSIONREADER_NO_EXPORT
#else
#  ifndef TTKTOPOLOGICALCOMPRESSIONREADER_EXPORT
#    ifdef ttkTopologicalCompressionReader_EXPORTS
        /* We are building this library */
#      define TTKTOPOLOGICALCOMPRESSIONREADER_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKTOPOLOGICALCOMPRESSIONREADER_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKTOPOLOGICALCOMPRESSIONREADER_NO_EXPORT
#    define TTKTOPOLOGICALCOMPRESSIONREADER_NO_EXPORT 
#  endif
#endif

#ifndef TTKTOPOLOGICALCOMPRESSIONREADER_DEPRECATED
#  define TTKTOPOLOGICALCOMPRESSIONREADER_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKTOPOLOGICALCOMPRESSIONREADER_DEPRECATED_EXPORT
#  define TTKTOPOLOGICALCOMPRESSIONREADER_DEPRECATED_EXPORT TTKTOPOLOGICALCOMPRESSIONREADER_EXPORT TTKTOPOLOGICALCOMPRESSIONREADER_DEPRECATED
#endif

#ifndef TTKTOPOLOGICALCOMPRESSIONREADER_DEPRECATED_NO_EXPORT
#  define TTKTOPOLOGICALCOMPRESSIONREADER_DEPRECATED_NO_EXPORT TTKTOPOLOGICALCOMPRESSIONREADER_NO_EXPORT TTKTOPOLOGICALCOMPRESSIONREADER_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKTOPOLOGICALCOMPRESSIONREADER_NO_DEPRECATED
#    define TTKTOPOLOGICALCOMPRESSIONREADER_NO_DEPRECATED
#  endif
#endif

#endif /* TTKTOPOLOGICALCOMPRESSIONREADER_EXPORT_H */
