
#ifndef TTKTABLEDATASELECTOR_EXPORT_H
#define TTKTABLEDATASELECTOR_EXPORT_H

#ifdef TTKTABLEDATASELECTOR_STATIC_DEFINE
#  define TTKTABLEDATASELECTOR_EXPORT
#  define TTKTABLEDATASELECTOR_NO_EXPORT
#else
#  ifndef TTKTABLEDATASELECTOR_EXPORT
#    ifdef ttkTableDataSelector_EXPORTS
        /* We are building this library */
#      define TTKTABLEDATASELECTOR_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKTABLEDATASELECTOR_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKTABLEDATASELECTOR_NO_EXPORT
#    define TTKTABLEDATASELECTOR_NO_EXPORT 
#  endif
#endif

#ifndef TTKTABLEDATASELECTOR_DEPRECATED
#  define TTKTABLEDATASELECTOR_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKTABLEDATASELECTOR_DEPRECATED_EXPORT
#  define TTKTABLEDATASELECTOR_DEPRECATED_EXPORT TTKTABLEDATASELECTOR_EXPORT TTKTABLEDATASELECTOR_DEPRECATED
#endif

#ifndef TTKTABLEDATASELECTOR_DEPRECATED_NO_EXPORT
#  define TTKTABLEDATASELECTOR_DEPRECATED_NO_EXPORT TTKTABLEDATASELECTOR_NO_EXPORT TTKTABLEDATASELECTOR_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKTABLEDATASELECTOR_NO_DEPRECATED
#    define TTKTABLEDATASELECTOR_NO_DEPRECATED
#  endif
#endif

#endif /* TTKTABLEDATASELECTOR_EXPORT_H */
