
#ifndef TTKPERSISTENCEDIAGRAM_EXPORT_H
#define TTKPERSISTENCEDIAGRAM_EXPORT_H

#ifdef TTKPERSISTENCEDIAGRAM_STATIC_DEFINE
#  define TTKPERSISTENCEDIAGRAM_EXPORT
#  define TTKPERSISTENCEDIAGRAM_NO_EXPORT
#else
#  ifndef TTKPERSISTENCEDIAGRAM_EXPORT
#    ifdef ttkPersistenceDiagram_EXPORTS
        /* We are building this library */
#      define TTKPERSISTENCEDIAGRAM_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKPERSISTENCEDIAGRAM_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKPERSISTENCEDIAGRAM_NO_EXPORT
#    define TTKPERSISTENCEDIAGRAM_NO_EXPORT 
#  endif
#endif

#ifndef TTKPERSISTENCEDIAGRAM_DEPRECATED
#  define TTKPERSISTENCEDIAGRAM_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKPERSISTENCEDIAGRAM_DEPRECATED_EXPORT
#  define TTKPERSISTENCEDIAGRAM_DEPRECATED_EXPORT TTKPERSISTENCEDIAGRAM_EXPORT TTKPERSISTENCEDIAGRAM_DEPRECATED
#endif

#ifndef TTKPERSISTENCEDIAGRAM_DEPRECATED_NO_EXPORT
#  define TTKPERSISTENCEDIAGRAM_DEPRECATED_NO_EXPORT TTKPERSISTENCEDIAGRAM_NO_EXPORT TTKPERSISTENCEDIAGRAM_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKPERSISTENCEDIAGRAM_NO_DEPRECATED
#    define TTKPERSISTENCEDIAGRAM_NO_DEPRECATED
#  endif
#endif

#endif /* TTKPERSISTENCEDIAGRAM_EXPORT_H */
