
#ifndef TTKCINEMAPRODUCTREADER_EXPORT_H
#define TTKCINEMAPRODUCTREADER_EXPORT_H

#ifdef TTKCINEMAPRODUCTREADER_STATIC_DEFINE
#  define TTKCINEMAPRODUCTREADER_EXPORT
#  define TTKCINEMAPRODUCTREADER_NO_EXPORT
#else
#  ifndef TTKCINEMAPRODUCTREADER_EXPORT
#    ifdef ttkCinemaProductReader_EXPORTS
        /* We are building this library */
#      define TTKCINEMAPRODUCTREADER_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKCINEMAPRODUCTREADER_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKCINEMAPRODUCTREADER_NO_EXPORT
#    define TTKCINEMAPRODUCTREADER_NO_EXPORT 
#  endif
#endif

#ifndef TTKCINEMAPRODUCTREADER_DEPRECATED
#  define TTKCINEMAPRODUCTREADER_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKCINEMAPRODUCTREADER_DEPRECATED_EXPORT
#  define TTKCINEMAPRODUCTREADER_DEPRECATED_EXPORT TTKCINEMAPRODUCTREADER_EXPORT TTKCINEMAPRODUCTREADER_DEPRECATED
#endif

#ifndef TTKCINEMAPRODUCTREADER_DEPRECATED_NO_EXPORT
#  define TTKCINEMAPRODUCTREADER_DEPRECATED_NO_EXPORT TTKCINEMAPRODUCTREADER_NO_EXPORT TTKCINEMAPRODUCTREADER_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKCINEMAPRODUCTREADER_NO_DEPRECATED
#    define TTKCINEMAPRODUCTREADER_NO_DEPRECATED
#  endif
#endif

#endif /* TTKCINEMAPRODUCTREADER_EXPORT_H */
