
#ifndef TTKPERSISTENCECURVE_EXPORT_H
#define TTKPERSISTENCECURVE_EXPORT_H

#ifdef TTKPERSISTENCECURVE_STATIC_DEFINE
#  define TTKPERSISTENCECURVE_EXPORT
#  define TTKPERSISTENCECURVE_NO_EXPORT
#else
#  ifndef TTKPERSISTENCECURVE_EXPORT
#    ifdef ttkPersistenceCurve_EXPORTS
        /* We are building this library */
#      define TTKPERSISTENCECURVE_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKPERSISTENCECURVE_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKPERSISTENCECURVE_NO_EXPORT
#    define TTKPERSISTENCECURVE_NO_EXPORT 
#  endif
#endif

#ifndef TTKPERSISTENCECURVE_DEPRECATED
#  define TTKPERSISTENCECURVE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKPERSISTENCECURVE_DEPRECATED_EXPORT
#  define TTKPERSISTENCECURVE_DEPRECATED_EXPORT TTKPERSISTENCECURVE_EXPORT TTKPERSISTENCECURVE_DEPRECATED
#endif

#ifndef TTKPERSISTENCECURVE_DEPRECATED_NO_EXPORT
#  define TTKPERSISTENCECURVE_DEPRECATED_NO_EXPORT TTKPERSISTENCECURVE_NO_EXPORT TTKPERSISTENCECURVE_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKPERSISTENCECURVE_NO_DEPRECATED
#    define TTKPERSISTENCECURVE_NO_DEPRECATED
#  endif
#endif

#endif /* TTKPERSISTENCECURVE_EXPORT_H */
