
#ifndef TTKPOINTMERGER_EXPORT_H
#define TTKPOINTMERGER_EXPORT_H

#ifdef TTKPOINTMERGER_STATIC_DEFINE
#  define TTKPOINTMERGER_EXPORT
#  define TTKPOINTMERGER_NO_EXPORT
#else
#  ifndef TTKPOINTMERGER_EXPORT
#    ifdef ttkPointMerger_EXPORTS
        /* We are building this library */
#      define TTKPOINTMERGER_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKPOINTMERGER_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKPOINTMERGER_NO_EXPORT
#    define TTKPOINTMERGER_NO_EXPORT 
#  endif
#endif

#ifndef TTKPOINTMERGER_DEPRECATED
#  define TTKPOINTMERGER_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKPOINTMERGER_DEPRECATED_EXPORT
#  define TTKPOINTMERGER_DEPRECATED_EXPORT TTKPOINTMERGER_EXPORT TTKPOINTMERGER_DEPRECATED
#endif

#ifndef TTKPOINTMERGER_DEPRECATED_NO_EXPORT
#  define TTKPOINTMERGER_DEPRECATED_NO_EXPORT TTKPOINTMERGER_NO_EXPORT TTKPOINTMERGER_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKPOINTMERGER_NO_DEPRECATED
#    define TTKPOINTMERGER_NO_DEPRECATED
#  endif
#endif

#endif /* TTKPOINTMERGER_EXPORT_H */
