
#ifndef TTKSTRINGARRAYCONVERTER_EXPORT_H
#define TTKSTRINGARRAYCONVERTER_EXPORT_H

#ifdef TTKSTRINGARRAYCONVERTER_STATIC_DEFINE
#  define TTKSTRINGARRAYCONVERTER_EXPORT
#  define TTKSTRINGARRAYCONVERTER_NO_EXPORT
#else
#  ifndef TTKSTRINGARRAYCONVERTER_EXPORT
#    ifdef ttkStringArrayConverter_EXPORTS
        /* We are building this library */
#      define TTKSTRINGARRAYCONVERTER_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKSTRINGARRAYCONVERTER_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKSTRINGARRAYCONVERTER_NO_EXPORT
#    define TTKSTRINGARRAYCONVERTER_NO_EXPORT 
#  endif
#endif

#ifndef TTKSTRINGARRAYCONVERTER_DEPRECATED
#  define TTKSTRINGARRAYCONVERTER_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKSTRINGARRAYCONVERTER_DEPRECATED_EXPORT
#  define TTKSTRINGARRAYCONVERTER_DEPRECATED_EXPORT TTKSTRINGARRAYCONVERTER_EXPORT TTKSTRINGARRAYCONVERTER_DEPRECATED
#endif

#ifndef TTKSTRINGARRAYCONVERTER_DEPRECATED_NO_EXPORT
#  define TTKSTRINGARRAYCONVERTER_DEPRECATED_NO_EXPORT TTKSTRINGARRAYCONVERTER_NO_EXPORT TTKSTRINGARRAYCONVERTER_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKSTRINGARRAYCONVERTER_NO_DEPRECATED
#    define TTKSTRINGARRAYCONVERTER_NO_DEPRECATED
#  endif
#endif

#endif /* TTKSTRINGARRAYCONVERTER_EXPORT_H */
