
#ifndef TTKCINEMAQUERY_EXPORT_H
#define TTKCINEMAQUERY_EXPORT_H

#ifdef TTKCINEMAQUERY_STATIC_DEFINE
#  define TTKCINEMAQUERY_EXPORT
#  define TTKCINEMAQUERY_NO_EXPORT
#else
#  ifndef TTKCINEMAQUERY_EXPORT
#    ifdef ttkCinemaQuery_EXPORTS
        /* We are building this library */
#      define TTKCINEMAQUERY_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKCINEMAQUERY_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKCINEMAQUERY_NO_EXPORT
#    define TTKCINEMAQUERY_NO_EXPORT 
#  endif
#endif

#ifndef TTKCINEMAQUERY_DEPRECATED
#  define TTKCINEMAQUERY_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKCINEMAQUERY_DEPRECATED_EXPORT
#  define TTKCINEMAQUERY_DEPRECATED_EXPORT TTKCINEMAQUERY_EXPORT TTKCINEMAQUERY_DEPRECATED
#endif

#ifndef TTKCINEMAQUERY_DEPRECATED_NO_EXPORT
#  define TTKCINEMAQUERY_DEPRECATED_NO_EXPORT TTKCINEMAQUERY_NO_EXPORT TTKCINEMAQUERY_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKCINEMAQUERY_NO_DEPRECATED
#    define TTKCINEMAQUERY_NO_DEPRECATED
#  endif
#endif

#endif /* TTKCINEMAQUERY_EXPORT_H */
