
#ifndef TTKMORSESMALEQUADRANGULATION_EXPORT_H
#define TTKMORSESMALEQUADRANGULATION_EXPORT_H

#ifdef TTKMORSESMALEQUADRANGULATION_STATIC_DEFINE
#  define TTKMORSESMALEQUADRANGULATION_EXPORT
#  define TTKMORSESMALEQUADRANGULATION_NO_EXPORT
#else
#  ifndef TTKMORSESMALEQUADRANGULATION_EXPORT
#    ifdef ttkMorseSmaleQuadrangulation_EXPORTS
        /* We are building this library */
#      define TTKMORSESMALEQUADRANGULATION_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKMORSESMALEQUADRANGULATION_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKMORSESMALEQUADRANGULATION_NO_EXPORT
#    define TTKMORSESMALEQUADRANGULATION_NO_EXPORT 
#  endif
#endif

#ifndef TTKMORSESMALEQUADRANGULATION_DEPRECATED
#  define TTKMORSESMALEQUADRANGULATION_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKMORSESMALEQUADRANGULATION_DEPRECATED_EXPORT
#  define TTKMORSESMALEQUADRANGULATION_DEPRECATED_EXPORT TTKMORSESMALEQUADRANGULATION_EXPORT TTKMORSESMALEQUADRANGULATION_DEPRECATED
#endif

#ifndef TTKMORSESMALEQUADRANGULATION_DEPRECATED_NO_EXPORT
#  define TTKMORSESMALEQUADRANGULATION_DEPRECATED_NO_EXPORT TTKMORSESMALEQUADRANGULATION_NO_EXPORT TTKMORSESMALEQUADRANGULATION_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKMORSESMALEQUADRANGULATION_NO_DEPRECATED
#    define TTKMORSESMALEQUADRANGULATION_NO_DEPRECATED
#  endif
#endif

#endif /* TTKMORSESMALEQUADRANGULATION_EXPORT_H */
