
#ifndef TTKMATRIXTOHEATMAP_EXPORT_H
#define TTKMATRIXTOHEATMAP_EXPORT_H

#ifdef TTKMATRIXTOHEATMAP_STATIC_DEFINE
#  define TTKMATRIXTOHEATMAP_EXPORT
#  define TTKMATRIXTOHEATMAP_NO_EXPORT
#else
#  ifndef TTKMATRIXTOHEATMAP_EXPORT
#    ifdef ttkMatrixToHeatMap_EXPORTS
        /* We are building this library */
#      define TTKMATRIXTOHEATMAP_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKMATRIXTOHEATMAP_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKMATRIXTOHEATMAP_NO_EXPORT
#    define TTKMATRIXTOHEATMAP_NO_EXPORT 
#  endif
#endif

#ifndef TTKMATRIXTOHEATMAP_DEPRECATED
#  define TTKMATRIXTOHEATMAP_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKMATRIXTOHEATMAP_DEPRECATED_EXPORT
#  define TTKMATRIXTOHEATMAP_DEPRECATED_EXPORT TTKMATRIXTOHEATMAP_EXPORT TTKMATRIXTOHEATMAP_DEPRECATED
#endif

#ifndef TTKMATRIXTOHEATMAP_DEPRECATED_NO_EXPORT
#  define TTKMATRIXTOHEATMAP_DEPRECATED_NO_EXPORT TTKMATRIXTOHEATMAP_NO_EXPORT TTKMATRIXTOHEATMAP_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKMATRIXTOHEATMAP_NO_DEPRECATED
#    define TTKMATRIXTOHEATMAP_NO_DEPRECATED
#  endif
#endif

#endif /* TTKMATRIXTOHEATMAP_EXPORT_H */
