
#ifndef TTKFIBER_EXPORT_H
#define TTKFIBER_EXPORT_H

#ifdef TTKFIBER_STATIC_DEFINE
#  define TTKFIBER_EXPORT
#  define TTKFIBER_NO_EXPORT
#else
#  ifndef TTKFIBER_EXPORT
#    ifdef ttkFiber_EXPORTS
        /* We are building this library */
#      define TTKFIBER_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKFIBER_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKFIBER_NO_EXPORT
#    define TTKFIBER_NO_EXPORT 
#  endif
#endif

#ifndef TTKFIBER_DEPRECATED
#  define TTKFIBER_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKFIBER_DEPRECATED_EXPORT
#  define TTKFIBER_DEPRECATED_EXPORT TTKFIBER_EXPORT TTKFIBER_DEPRECATED
#endif

#ifndef TTKFIBER_DEPRECATED_NO_EXPORT
#  define TTKFIBER_DEPRECATED_NO_EXPORT TTKFIBER_NO_EXPORT TTKFIBER_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKFIBER_NO_DEPRECATED
#    define TTKFIBER_NO_DEPRECATED
#  endif
#endif

#endif /* TTKFIBER_EXPORT_H */
