
#ifndef TTKTOPOLOGICALCOMPRESSIONWRITER_EXPORT_H
#define TTKTOPOLOGICALCOMPRESSIONWRITER_EXPORT_H

#ifdef TTKTOPOLOGICALCOMPRESSIONWRITER_STATIC_DEFINE
#  define TTKTOPOLOGICALCOMPRESSIONWRITER_EXPORT
#  define TTKTOPOLOGICALCOMPRESSIONWRITER_NO_EXPORT
#else
#  ifndef TTKTOPOLOGICALCOMPRESSIONWRITER_EXPORT
#    ifdef ttkTopologicalCompressionWriter_EXPORTS
        /* We are building this library */
#      define TTKTOPOLOGICALCOMPRESSIONWRITER_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKTOPOLOGICALCOMPRESSIONWRITER_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKTOPOLOGICALCOMPRESSIONWRITER_NO_EXPORT
#    define TTKTOPOLOGICALCOMPRESSIONWRITER_NO_EXPORT 
#  endif
#endif

#ifndef TTKTOPOLOGICALCOMPRESSIONWRITER_DEPRECATED
#  define TTKTOPOLOGICALCOMPRESSIONWRITER_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKTOPOLOGICALCOMPRESSIONWRITER_DEPRECATED_EXPORT
#  define TTKTOPOLOGICALCOMPRESSIONWRITER_DEPRECATED_EXPORT TTKTOPOLOGICALCOMPRESSIONWRITER_EXPORT TTKTOPOLOGICALCOMPRESSIONWRITER_DEPRECATED
#endif

#ifndef TTKTOPOLOGICALCOMPRESSIONWRITER_DEPRECATED_NO_EXPORT
#  define TTKTOPOLOGICALCOMPRESSIONWRITER_DEPRECATED_NO_EXPORT TTKTOPOLOGICALCOMPRESSIONWRITER_NO_EXPORT TTKTOPOLOGICALCOMPRESSIONWRITER_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKTOPOLOGICALCOMPRESSIONWRITER_NO_DEPRECATED
#    define TTKTOPOLOGICALCOMPRESSIONWRITER_NO_DEPRECATED
#  endif
#endif

#endif /* TTKTOPOLOGICALCOMPRESSIONWRITER_EXPORT_H */
