
#ifndef TTKDATASETTOTABLE_EXPORT_H
#define TTKDATASETTOTABLE_EXPORT_H

#ifdef TTKDATASETTOTABLE_STATIC_DEFINE
#  define TTKDATASETTOTABLE_EXPORT
#  define TTKDATASETTOTABLE_NO_EXPORT
#else
#  ifndef TTKDATASETTOTABLE_EXPORT
#    ifdef ttkDataSetToTable_EXPORTS
        /* We are building this library */
#      define TTKDATASETTOTABLE_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKDATASETTOTABLE_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKDATASETTOTABLE_NO_EXPORT
#    define TTKDATASETTOTABLE_NO_EXPORT 
#  endif
#endif

#ifndef TTKDATASETTOTABLE_DEPRECATED
#  define TTKDATASETTOTABLE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKDATASETTOTABLE_DEPRECATED_EXPORT
#  define TTKDATASETTOTABLE_DEPRECATED_EXPORT TTKDATASETTOTABLE_EXPORT TTKDATASETTOTABLE_DEPRECATED
#endif

#ifndef TTKDATASETTOTABLE_DEPRECATED_NO_EXPORT
#  define TTKDATASETTOTABLE_DEPRECATED_NO_EXPORT TTKDATASETTOTABLE_NO_EXPORT TTKDATASETTOTABLE_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKDATASETTOTABLE_NO_DEPRECATED
#    define TTKDATASETTOTABLE_NO_DEPRECATED
#  endif
#endif

#endif /* TTKDATASETTOTABLE_EXPORT_H */
