
#ifndef TTKJACOBISET_EXPORT_H
#define TTKJACOBISET_EXPORT_H

#ifdef TTKJACOBISET_STATIC_DEFINE
#  define TTKJACOBISET_EXPORT
#  define TTKJACOBISET_NO_EXPORT
#else
#  ifndef TTKJACOBISET_EXPORT
#    ifdef ttkJacobiSet_EXPORTS
        /* We are building this library */
#      define TTKJACOBISET_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKJACOBISET_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKJACOBISET_NO_EXPORT
#    define TTKJACOBISET_NO_EXPORT 
#  endif
#endif

#ifndef TTKJACOBISET_DEPRECATED
#  define TTKJACOBISET_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKJACOBISET_DEPRECATED_EXPORT
#  define TTKJACOBISET_DEPRECATED_EXPORT TTKJACOBISET_EXPORT TTKJACOBISET_DEPRECATED
#endif

#ifndef TTKJACOBISET_DEPRECATED_NO_EXPORT
#  define TTKJACOBISET_DEPRECATED_NO_EXPORT TTKJACOBISET_NO_EXPORT TTKJACOBISET_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKJACOBISET_NO_DEPRECATED
#    define TTKJACOBISET_NO_DEPRECATED
#  endif
#endif

#endif /* TTKJACOBISET_EXPORT_H */
