
#ifndef TTKTRACKINGFROMFIELDS_EXPORT_H
#define TTKTRACKINGFROMFIELDS_EXPORT_H

#ifdef TTKTRACKINGFROMFIELDS_STATIC_DEFINE
#  define TTKTRACKINGFROMFIELDS_EXPORT
#  define TTKTRACKINGFROMFIELDS_NO_EXPORT
#else
#  ifndef TTKTRACKINGFROMFIELDS_EXPORT
#    ifdef ttkTrackingFromFields_EXPORTS
        /* We are building this library */
#      define TTKTRACKINGFROMFIELDS_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKTRACKINGFROMFIELDS_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKTRACKINGFROMFIELDS_NO_EXPORT
#    define TTKTRACKINGFROMFIELDS_NO_EXPORT 
#  endif
#endif

#ifndef TTKTRACKINGFROMFIELDS_DEPRECATED
#  define TTKTRACKINGFROMFIELDS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKTRACKINGFROMFIELDS_DEPRECATED_EXPORT
#  define TTKTRACKINGFROMFIELDS_DEPRECATED_EXPORT TTKTRACKINGFROMFIELDS_EXPORT TTKTRACKINGFROMFIELDS_DEPRECATED
#endif

#ifndef TTKTRACKINGFROMFIELDS_DEPRECATED_NO_EXPORT
#  define TTKTRACKINGFROMFIELDS_DEPRECATED_NO_EXPORT TTKTRACKINGFROMFIELDS_NO_EXPORT TTKTRACKINGFROMFIELDS_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKTRACKINGFROMFIELDS_NO_DEPRECATED
#    define TTKTRACKINGFROMFIELDS_NO_DEPRECATED
#  endif
#endif

#endif /* TTKTRACKINGFROMFIELDS_EXPORT_H */
