
#ifndef TTKCINEMAREADER_EXPORT_H
#define TTKCINEMAREADER_EXPORT_H

#ifdef TTKCINEMAREADER_STATIC_DEFINE
#  define TTKCINEMAREADER_EXPORT
#  define TTKCINEMAREADER_NO_EXPORT
#else
#  ifndef TTKCINEMAREADER_EXPORT
#    ifdef ttkCinemaReader_EXPORTS
        /* We are building this library */
#      define TTKCINEMAREADER_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKCINEMAREADER_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKCINEMAREADER_NO_EXPORT
#    define TTKCINEMAREADER_NO_EXPORT 
#  endif
#endif

#ifndef TTKCINEMAREADER_DEPRECATED
#  define TTKCINEMAREADER_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKCINEMAREADER_DEPRECATED_EXPORT
#  define TTKCINEMAREADER_DEPRECATED_EXPORT TTKCINEMAREADER_EXPORT TTKCINEMAREADER_DEPRECATED
#endif

#ifndef TTKCINEMAREADER_DEPRECATED_NO_EXPORT
#  define TTKCINEMAREADER_DEPRECATED_NO_EXPORT TTKCINEMAREADER_NO_EXPORT TTKCINEMAREADER_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKCINEMAREADER_NO_DEPRECATED
#    define TTKCINEMAREADER_NO_DEPRECATED
#  endif
#endif

#endif /* TTKCINEMAREADER_EXPORT_H */
