
#ifndef TTKUNCERTAINDATAESTIMATOR_EXPORT_H
#define TTKUNCERTAINDATAESTIMATOR_EXPORT_H

#ifdef TTKUNCERTAINDATAESTIMATOR_STATIC_DEFINE
#  define TTKUNCERTAINDATAESTIMATOR_EXPORT
#  define TTKUNCERTAINDATAESTIMATOR_NO_EXPORT
#else
#  ifndef TTKUNCERTAINDATAESTIMATOR_EXPORT
#    ifdef ttkUncertainDataEstimator_EXPORTS
        /* We are building this library */
#      define TTKUNCERTAINDATAESTIMATOR_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKUNCERTAINDATAESTIMATOR_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKUNCERTAINDATAESTIMATOR_NO_EXPORT
#    define TTKUNCERTAINDATAESTIMATOR_NO_EXPORT 
#  endif
#endif

#ifndef TTKUNCERTAINDATAESTIMATOR_DEPRECATED
#  define TTKUNCERTAINDATAESTIMATOR_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKUNCERTAINDATAESTIMATOR_DEPRECATED_EXPORT
#  define TTKUNCERTAINDATAESTIMATOR_DEPRECATED_EXPORT TTKUNCERTAINDATAESTIMATOR_EXPORT TTKUNCERTAINDATAESTIMATOR_DEPRECATED
#endif

#ifndef TTKUNCERTAINDATAESTIMATOR_DEPRECATED_NO_EXPORT
#  define TTKUNCERTAINDATAESTIMATOR_DEPRECATED_NO_EXPORT TTKUNCERTAINDATAESTIMATOR_NO_EXPORT TTKUNCERTAINDATAESTIMATOR_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKUNCERTAINDATAESTIMATOR_NO_DEPRECATED
#    define TTKUNCERTAINDATAESTIMATOR_NO_DEPRECATED
#  endif
#endif

#endif /* TTKUNCERTAINDATAESTIMATOR_EXPORT_H */
