
#ifndef TTKSCALARFIELDSMOOTHER_EXPORT_H
#define TTKSCALARFIELDSMOOTHER_EXPORT_H

#ifdef TTKSCALARFIELDSMOOTHER_STATIC_DEFINE
#  define TTKSCALARFIELDSMOOTHER_EXPORT
#  define TTKSCALARFIELDSMOOTHER_NO_EXPORT
#else
#  ifndef TTKSCALARFIELDSMOOTHER_EXPORT
#    ifdef ttkScalarFieldSmoother_EXPORTS
        /* We are building this library */
#      define TTKSCALARFIELDSMOOTHER_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKSCALARFIELDSMOOTHER_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKSCALARFIELDSMOOTHER_NO_EXPORT
#    define TTKSCALARFIELDSMOOTHER_NO_EXPORT 
#  endif
#endif

#ifndef TTKSCALARFIELDSMOOTHER_DEPRECATED
#  define TTKSCALARFIELDSMOOTHER_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKSCALARFIELDSMOOTHER_DEPRECATED_EXPORT
#  define TTKSCALARFIELDSMOOTHER_DEPRECATED_EXPORT TTKSCALARFIELDSMOOTHER_EXPORT TTKSCALARFIELDSMOOTHER_DEPRECATED
#endif

#ifndef TTKSCALARFIELDSMOOTHER_DEPRECATED_NO_EXPORT
#  define TTKSCALARFIELDSMOOTHER_DEPRECATED_NO_EXPORT TTKSCALARFIELDSMOOTHER_NO_EXPORT TTKSCALARFIELDSMOOTHER_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKSCALARFIELDSMOOTHER_NO_DEPRECATED
#    define TTKSCALARFIELDSMOOTHER_NO_DEPRECATED
#  endif
#endif

#endif /* TTKSCALARFIELDSMOOTHER_EXPORT_H */
