
#ifndef TTKPOINTDATACONVERTER_EXPORT_H
#define TTKPOINTDATACONVERTER_EXPORT_H

#ifdef TTKPOINTDATACONVERTER_STATIC_DEFINE
#  define TTKPOINTDATACONVERTER_EXPORT
#  define TTKPOINTDATACONVERTER_NO_EXPORT
#else
#  ifndef TTKPOINTDATACONVERTER_EXPORT
#    ifdef ttkPointDataConverter_EXPORTS
        /* We are building this library */
#      define TTKPOINTDATACONVERTER_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKPOINTDATACONVERTER_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKPOINTDATACONVERTER_NO_EXPORT
#    define TTKPOINTDATACONVERTER_NO_EXPORT 
#  endif
#endif

#ifndef TTKPOINTDATACONVERTER_DEPRECATED
#  define TTKPOINTDATACONVERTER_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKPOINTDATACONVERTER_DEPRECATED_EXPORT
#  define TTKPOINTDATACONVERTER_DEPRECATED_EXPORT TTKPOINTDATACONVERTER_EXPORT TTKPOINTDATACONVERTER_DEPRECATED
#endif

#ifndef TTKPOINTDATACONVERTER_DEPRECATED_NO_EXPORT
#  define TTKPOINTDATACONVERTER_DEPRECATED_NO_EXPORT TTKPOINTDATACONVERTER_NO_EXPORT TTKPOINTDATACONVERTER_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKPOINTDATACONVERTER_NO_DEPRECATED
#    define TTKPOINTDATACONVERTER_NO_DEPRECATED
#  endif
#endif

#endif /* TTKPOINTDATACONVERTER_EXPORT_H */
