
#ifndef TTKHARMONICFIELD_EXPORT_H
#define TTKHARMONICFIELD_EXPORT_H

#ifdef TTKHARMONICFIELD_STATIC_DEFINE
#  define TTKHARMONICFIELD_EXPORT
#  define TTKHARMONICFIELD_NO_EXPORT
#else
#  ifndef TTKHARMONICFIELD_EXPORT
#    ifdef ttkHarmonicField_EXPORTS
        /* We are building this library */
#      define TTKHARMONICFIELD_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define TTKHARMONICFIELD_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef TTKHARMONICFIELD_NO_EXPORT
#    define TTKHARMONICFIELD_NO_EXPORT 
#  endif
#endif

#ifndef TTKHARMONICFIELD_DEPRECATED
#  define TTKHARMONICFIELD_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TTKHARMONICFIELD_DEPRECATED_EXPORT
#  define TTKHARMONICFIELD_DEPRECATED_EXPORT TTKHARMONICFIELD_EXPORT TTKHARMONICFIELD_DEPRECATED
#endif

#ifndef TTKHARMONICFIELD_DEPRECATED_NO_EXPORT
#  define TTKHARMONICFIELD_DEPRECATED_NO_EXPORT TTKHARMONICFIELD_NO_EXPORT TTKHARMONICFIELD_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TTKHARMONICFIELD_NO_DEPRECATED
#    define TTKHARMONICFIELD_NO_DEPRECATED
#  endif
#endif

#endif /* TTKHARMONICFIELD_EXPORT_H */
